@@ -4,4 +4,4 @@ from django.apps import AppConfig
 
 class TextCkeditorConfig(AppConfig):
     name = 'djangocms_text_ckeditor'
-    verbose_name = "Text CKEditor"
+    verbose_name = 'django CMS Text CKEditor'
