@@ -1,9 +1,10 @@
 # -*- coding: utf-8 -*-
 import os
 
-from cms.models.pluginmodel import CMSPlugin
 from django.conf import settings
 
+from cms.models.pluginmodel import CMSPlugin
+
 
 def create_picture_plugin(filename, file, parent_plugin, **kwargs):
     try:
@@ -22,7 +23,7 @@ def create_picture_plugin(filename, file, parent_plugin, **kwargs):
     if not os.path.exists(os.path.dirname(full_path)):
         os.makedirs(os.path.dirname(full_path))
     pic.image = path
-    f = open(full_path, "wb")
+    f = open(full_path, 'wb')
     f.write(file.read())
     f.close()
     pic.save()
